django-garage
=============

Django-garage is a collection of useful functions and modules for
building Django applications and projects.

Current version: 0.1.11


## Contact Info

For questions about this application, please email Kevin Chan at
kefin@makedostudio.com.

On bitbucket:

* https://bitbucket.org/kchan/django-garage
